Crate sh_exec

Macros

exec
trap_panics_and_errors
trap_panics_and_errors traps panics that might be issued when calling a given function It will print a nice error message in case a panic is trapped. This macro also traps errors, prints the error and exists the program with error code 1

Structs

ShellError
Custom error type for shell command execution

Functions

execute_command
Executes a shell command and returns a Result containing the command’s output
get_env
main_run