Function get_env

pub fn get_env(
    env: &str,
    error_id: &'static str,
) -> Result<String, ShellError<'static>>
read the content of a given environment variable as a String if the environment variable does not exist, return a ShellError