pub fn run_with_diagnostics<F>(f: F)where F: FnOnce() -> Result<()>,
Main runner that handles errors with nice formatting
This function runs your main logic and prints diagnostic information if an error occurs, including cargo package metadata.