a

Macro a 

macro_rules! a {
    ($error_id:literal , $duration:tt, $($cmd:tt )* ) => { ... };
}
Execute a shell command and return the output The command is formatted using the given arguments The command is printed at the INFO level The output of the command is printed at the DEBUG level In case of an error, the error is printed at the ERROR level The error is returned