macro_rules! exec {
($error_id:literal , $verbose:expr , $($cmd:tt )* ) => { ... };
}Expand description
Execute a shell command and return the output The command is formatted using the given arguments The command is printed if the verbose flag is set to true (useful for debugging)